@@ -14,7 +14,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, Dict, IO, TYPE_CHECKING, Union
+from typing import Any, Dict, IO, TYPE_CHECKING, Type, Union
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_codeguruprofiler.type_defs import (
     AgentOrchestrationConfigTypeDef,
@@ -37,32 +37,32 @@ __all__ = ("CodeGuruProfilerClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    ConflictException: Boto3ClientError
-    InternalServerException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ServiceQuotaExceededException: Boto3ClientError
-    ThrottlingException: Boto3ClientError
-    ValidationException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    ConflictException: Type[Boto3ClientError]
+    InternalServerException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ServiceQuotaExceededException: Type[Boto3ClientError]
+    ThrottlingException: Type[Boto3ClientError]
+    ValidationException: Type[Boto3ClientError]
 
 
 class CodeGuruProfilerClient:
     """
-    [CodeGuruProfiler.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
+    [CodeGuruProfiler.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
         """
 
     def configure_agent(
         self, profilingGroupName: str, fleetInstanceId: str = None
     ) -> ConfigureAgentResponseTypeDef:
         """
-        [Client.configure_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
+        [Client.configure_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
         """
 
     def create_profiling_group(
@@ -72,19 +72,19 @@ class CodeGuruProfilerClient:
         agentOrchestrationConfig: AgentOrchestrationConfigTypeDef = None,
     ) -> CreateProfilingGroupResponseTypeDef:
         """
-        [Client.create_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
+        [Client.create_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
         """
 
     def delete_profiling_group(self, profilingGroupName: str) -> Dict[str, Any]:
         """
-        [Client.delete_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
+        [Client.delete_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
         """
 
     def describe_profiling_group(
         self, profilingGroupName: str
     ) -> DescribeProfilingGroupResponseTypeDef:
         """
-        [Client.describe_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
+        [Client.describe_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
         """
 
     def generate_presigned_url(
@@ -95,7 +95,7 @@ class CodeGuruProfilerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
         """
 
     def get_profile(
@@ -108,7 +108,7 @@ class CodeGuruProfilerClient:
         startTime: datetime = None,
     ) -> GetProfileResponseTypeDef:
         """
-        [Client.get_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
+        [Client.get_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
         """
 
     def list_profile_times(
@@ -122,14 +122,14 @@ class CodeGuruProfilerClient:
         orderBy: Literal["TimestampAscending", "TimestampDescending"] = None,
     ) -> ListProfileTimesResponseTypeDef:
         """
-        [Client.list_profile_times documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
+        [Client.list_profile_times documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
         """
 
     def list_profiling_groups(
         self, includeDescription: bool = None, maxResults: int = None, nextToken: str = None
     ) -> ListProfilingGroupsResponseTypeDef:
         """
-        [Client.list_profiling_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
+        [Client.list_profiling_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
         """
 
     def post_agent_profile(
@@ -140,12 +140,12 @@ class CodeGuruProfilerClient:
         profileToken: str = None,
     ) -> Dict[str, Any]:
         """
-        [Client.post_agent_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
+        [Client.post_agent_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
         """
 
     def update_profiling_group(
         self, agentOrchestrationConfig: AgentOrchestrationConfigTypeDef, profilingGroupName: str
     ) -> UpdateProfilingGroupResponseTypeDef:
         """
-        [Client.update_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
+        [Client.update_profiling_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.33/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
         """
